==> gura-0.6.2-src.tar.gz: gura-0.6.2/src/module-wx/Class_wx_ScopedTiedPtr.h <==
//----------------------------------------------------------------------------
// wxScopedTiedPtr
// extracted from scpdptr.tex
//----------------------------------------------------------------------------
#ifndef __CLASS_WX_SCOPEDTIEDPTR_H__
#define __CLASS_WX_SCOPEDTIEDPTR_H__

Gura_BeginModuleScope(wx)

//----------------------------------------------------------------------------
// Class declaration for wxScopedTiedPtr
//----------------------------------------------------------------------------
Gura_DeclareUserClass(wx_ScopedTiedPtr);

//----------------------------------------------------------------------------
// Object declaration for wxScopedTiedPtr
//----------------------------------------------------------------------------
class Object_wx_ScopedTiedPtr : public Object_wx_ScopedPtr {
public:
	Gura_DeclareObjectAccessor(wx_ScopedTiedPtr)
public:
	inline Object_wx_ScopedTiedPtr(wxScopedTiedPtr *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) :
				Object_wx_ScopedPtr(Gura_UserClass(wx_ScopedTiedPtr), pEntity, pObserver, ownerFlag) {}
	inline Object_wx_ScopedTiedPtr(Class *pClass, wxScopedTiedPtr *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) :
				Object_wx_ScopedPtr(pClass, pEntity, pObserver, ownerFlag) {}
	virtual ~Object_wx_ScopedTiedPtr();
	virtual Object *Clone() const;
	virtual String ToString(bool exprFlag);
	inline wxScopedTiedPtr *GetEntity() {
		return dynamic_cast<wxScopedTiedPtr *>(_pEntity);
	}
	inline wxScopedTiedPtr *ReleaseEntity() {
		wxScopedTiedPtr *pEntity = GetEntity();
		InvalidateEntity();
		return pEntity;
	}
	inline bool IsInvalid(Signal sig) const {
		if (_pEntity != NULL) return false;
		SetError_InvalidWxObject(sig, "wxScopedTiedPtr");
		return true;
	}
};

Gura_EndModuleScope(wx)

#endif

==> gura-0.7.0-src.tar.gz: gura-0.7.0/src/module-wx/Class_wx_ScopedTiedPtr.h <==
//----------------------------------------------------------------------------
// wxScopedTiedPtr
// extracted from scpdptr.tex
//----------------------------------------------------------------------------
#ifndef __CLASS_WX_SCOPEDTIEDPTR_H__
#define __CLASS_WX_SCOPEDTIEDPTR_H__

Gura_BeginModuleScope(wx)

//----------------------------------------------------------------------------
// Class declaration for wxScopedTiedPtr
//----------------------------------------------------------------------------
Gura_DeclareUserClass(wx_ScopedTiedPtr);

//----------------------------------------------------------------------------
// Object declaration for wxScopedTiedPtr
//----------------------------------------------------------------------------
class Object_wx_ScopedTiedPtr : public Object_wx_ScopedPtr {
public:
	Gura_DeclareObjectAccessor(wx_ScopedTiedPtr)
public:
	inline Object_wx_ScopedTiedPtr(wxScopedTiedPtr *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) :
				Object_wx_ScopedPtr(Gura_UserClass(wx_ScopedTiedPtr), pEntity, pObserver, ownerFlag) {}
	inline Object_wx_ScopedTiedPtr(Class *pClass, wxScopedTiedPtr *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) :
				Object_wx_ScopedPtr(pClass, pEntity, pObserver, ownerFlag) {}
	virtual ~Object_wx_ScopedTiedPtr();
	virtual Object *Clone() const;
	virtual String ToString(bool exprFlag);
	inline wxScopedTiedPtr *GetEntity() {
		return dynamic_cast<wxScopedTiedPtr *>(_pEntity);
	}
	inline wxScopedTiedPtr *ReleaseEntity() {
		wxScopedTiedPtr *pEntity = GetEntity();
		InvalidateEntity();
		return pEntity;
	}
	inline bool IsInvalid(Signal &sig) const {
		if (_pEntity != nullptr) return false;
		SetError_InvalidWxObject(sig, "wxScopedTiedPtr");
		return true;
	}
};

Gura_EndModuleScope(wx)

#endif
